<?php

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'WP_Radio_Admin' ) ) {
	class WP_Radio_Admin {

		private static $instance = null;

		/**
		 * Admin constructor.
		 */
		public function __construct() {
			add_action( 'admin_menu', [ $this, 'admin_menu' ] );

			add_action( 'admin_init', [ $this, 'init_update' ] );
			add_action( 'admin_init', [ $this, 'remove_country' ] );

			add_action( 'pre_get_posts', [ $this, 'pre_get_posts' ] );
			add_action( 'restrict_manage_posts', [ $this, 'add_posts_filter_field' ] );
			add_filter( 'display_post_states', [ $this, 'station_page_status' ], 10, 2 );

			add_action( 'admin_init', [ $this, 'flush_rewrite_rules' ] );

			/*Add ID column to the posts table*/
			add_filter( 'manage_edit-wp_radio_columns', [ $this, 'custom_set_posts_columns' ] );
			add_action( 'manage_posts_custom_column', [ $this, 'custom_set_posts_columns_value' ], 10, 2 );

			add_action( 'admin_menu', array( $this, 'recommended_plugins_menu' ), 11 );

		}

		public function recommended_plugins_menu() {
			if ( isset( $_GET['hide_wp_radio_recommended_plugin'] ) && isset( $_GET['nonce'] ) ) {
				if ( current_user_can( 'manage_options' ) ) {
					$nonce = $_GET['nonce'];
					if ( wp_verify_nonce( $nonce, 'wp_radio_recommended_plugin' ) ) {
						update_option( 'hide_wp_radio_recommended_plugin', true );
					}
				}
			}

			if ( ! get_option( 'hide_wp_radio_recommended_plugin' ) ) {
				add_submenu_page(
					'edit.php?post_type=wp_radio', 'Recommended Plugins', 'Recommended Plugins', 'manage_options',
					'wp-radio-recommended-plugins', [ $this, 'recommended_plugins_page' ], 99
				);
			}
		}


		public function custom_set_posts_columns( $columns ) {
			return array(
				'cb'                     => '<input type="checkbox" />',
				'id'                     => __( 'ID', 'wp-radio' ),
				'title'                  => __( 'Title', 'wp-radio' ),
				'taxonomy-radio_country' => __( 'Country', 'wp-radio' ),
				'taxonomy-radio_genre'   => __( 'Genre', 'wp-radio' ),
				'date'                   => __( 'Date', 'wp-radio' ),
			);
		}

		public function custom_set_posts_columns_value( $column, $post_id ) {
			if ( 'wp_radio' == get_post_type( $post_id ) && $column == 'id' ) {
				echo $post_id;
			}
		}


		/**
		 * set flush_rewrite_rules for update
		 *
		 * @param $options
		 */
		public function flush_rewrite_rules() {
			if ( ! isset( $_POST['wp_radio_permalink_settings'] ) ) {
				return;
			}

			update_option( 'permalink_structure', '/%postname%/' );
			update_option( 'wp_radio_flush_rewrite_rules', true );
		}

		/**
		 * Run Update
		 *
		 * @return void
		 * @since 2.0.8
		 *
		 */
		public function init_update() {

			if ( ! class_exists( 'WP_Radio_Update' ) && current_user_can( 'manage_options' ) ) {
				include_once WP_RADIO_INCLUDES . '/admin/class-update.php';

				$updater = WP_Radio_Update::instance();
				if ( $updater->needs_update() ) {
					$updater->perform_updates();
				}
			}
		}

		/**
		 * Add post filter field
		 *
		 * @return void
		 */
		public function add_posts_filter_field() {
			$type = ! empty( $_GET['post_type'] ) ? sanitize_key( $_GET['post_type'] ) : '';

			if ( 'wp_radio' == $type ) { ?>
                <select name="country">
                    <option value=""><?php _e( 'All Countries', 'wp-radio' ); ?></option>
					<?php
					$countries = get_terms( [ 'taxonomy' => 'radio_country', 'parent' => 0 ] );

					if ( ! empty( $countries ) ) {

						foreach ( $countries as $country ) {
							printf( '<option value="%1$s" %2$s >%3$s</option>', $country->slug, selected( $country->slug, ! empty( $_GET['country'] ) ? $_GET['country'] : '' ), $country->name );
						}
					}
					?>
                </select>
				<?php
			}
		}

		public function pre_get_posts( $query ) {

			if ( ! is_admin() ) {
				return;
			}

			global $pagenow;
			$is_edit       = 'edit.php' == $pagenow;
			$is_type       = ! empty( $query->query_vars['post_type'] ) && 'wp_radio' == $query->query_vars['post_type'];
			$is_main_query = $query->is_main_query();

			if ( $is_edit && $is_type && $is_main_query ) {


				if ( ! empty( $_GET['country'] ) ) {
					$query->query_vars['tax_query'] = [
						'relation' => 'AND',
						[
							'taxonomy' => 'radio_country',
							'field'    => 'slug',
							'terms'    => sanitize_text_field( $_GET['country'] ),
						]
					];
				}

			}

		}

		/**
		 * Add admin menu
		 *
		 * @return void
		 * @since 2.0.7
		 *
		 */
		public function admin_menu() {

			add_submenu_page( 'edit.php?post_type=wp_radio', __( 'Get Started', 'wp-radio' ), __( 'Get Started', 'wp-radio' ), 'manage_options', 'get-started', [
				$this,
				'get_started_page'
			] );

			add_submenu_page( 'edit.php?post_type=wp_radio', __( 'Import Stations', 'wp-radio' ), __( 'Import Stations', 'wp-radio' ), 'manage_options', 'import-stations', [
				$this,
				'import_menu_page'
			] );

			add_submenu_page( 'edit.php?post_type=wp_radio', __( 'Statistics', 'wp-radio' ), __( 'Statistics', 'wp-radio' ), 'manage_options', 'statistics', [
				$this,
				'render_statistics_page'
			] );


		}

		public function get_started_page() {
			include WP_RADIO_INCLUDES . '/admin/views/get-started/index.php';
		}

		public function recommended_plugins_page() {
			include_once WP_RADIO_INCLUDES . '/admin/views/recommended-plugins.php';
		}


		/**
		 * Import Page
		 */
		public function import_menu_page() {
			include WP_RADIO_INCLUDES . '/admin/views/html-import-stations.php';
		}

		/**
		 * Statistics Page
		 */
		public function render_statistics_page() {
			include WP_RADIO_INCLUDES . '/admin/views/statistics.php';
		}


		/**
		 * Add status for radios base page
		 *
		 * @param $states
		 * @param $post
		 *
		 * @return array
		 */
		public function station_page_status( $states, $post ) {

			if ( wp_radio_get_settings( 'stations_page' ) == $post->ID ) {

				$states[] = __( 'Radio Archive', 'wp-radio' );

			}

			return $states;
		}


		/**
		 * Remove country and it's stations from import page,
		 *
		 * @return void
		 * @since 2.0.7
		 *
		 */
		public function remove_country() {

			if ( empty( $_GET['action'] ) || empty( $_GET['country'] ) || sanitize_key( $_GET['action'] ) != 'remove' || ! wp_verify_nonce( $_GET['nonce'], 'wp-radio' ) || ! current_user_can( 'delete_posts' ) ) {
				return;
			}

			$country = sanitize_key( $_GET['country'] );
			global $wpdb;

			$term_id  = $wpdb->get_var( $wpdb->prepare( "SELECT term_id FROM {$wpdb->terms} WHERE slug = %s", $country ) );
			$post_ids = $wpdb->get_col( $wpdb->prepare( "SELECT object_id FROM {$wpdb->term_relationships} WHERE term_taxonomy_id = %d;", $term_id ) );

			if ( ! empty( $post_ids ) ) {

				$placeholders = '';
				foreach ( $post_ids as $post_id ) {
					$placeholders .= '%s,';
				}

				$prepared_placeholders = trim( $placeholders, ',' );
				$prepared_values       = array_merge( array( 'wp_radio' ), $post_ids );

				// Delete posts + data.
				$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->posts} WHERE post_type = %s AND ID IN ($prepared_placeholders);", $prepared_values ) );
				$wpdb->query( "DELETE meta FROM {$wpdb->postmeta} meta LEFT JOIN {$wpdb->posts} posts ON posts.ID = meta.post_id WHERE posts.ID IS NULL;" );
			}

			//delete child category
			$children = get_term_children( $term_id, 'radio_country' );

			if ( ! empty( $children ) ) {
				foreach ( $children as $children_id ) {
					wp_delete_term( $children_id, 'radio_country' );
				}
			}

			wp_delete_term( $term_id, 'radio_country' );

			// Delete orphan relationships.
			$wpdb->query( "DELETE tr FROM {$wpdb->term_relationships} tr LEFT JOIN {$wpdb->posts} posts ON posts.ID = tr.object_id WHERE posts.ID IS NULL;" );

			// Delete orphan terms.
			$wpdb->query( "DELETE t FROM {$wpdb->terms} t LEFT JOIN {$wpdb->term_taxonomy} tt ON t.term_id = tt.term_id WHERE tt.term_id IS NULL;" );

			// Delete orphan term meta.
			if ( ! empty( $wpdb->termmeta ) ) {
				$wpdb->query( "DELETE tm FROM {$wpdb->termmeta} tm LEFT JOIN {$wpdb->term_taxonomy} tt ON tm.term_id = tt.term_id WHERE tt.term_id IS NULL;" );
			}

			// Clear any cached data that has been removed.
			wp_cache_flush();

			$option_key = ! empty( $_REQUEST['type'] ) ? wp_unslash( $_REQUEST['type'] ) : 'wp_radio_imported_countries';


			$countries = (array) get_option( $option_key );
			if ( ( $key = array_search( $country, $countries ) ) !== false ) {
				unset( $countries[ $key ] );
			}

			update_option( $option_key, $countries );

			$redirect_page = 'wp_radio_imported_countries' == $option_key ? 'import-stations' : 'import-radios';

			wp_redirect( admin_url( 'edit.php?post_type=wp_radio&page=' . $redirect_page ) );

		}


		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

	}
}

WP_Radio_Admin::instance();