<?php

defined( 'ABSPATH' ) || exit;
if ( !class_exists( 'WP_Radio_Chart_Widget' ) ) {
    class WP_Radio_Chart_Widget
    {
        /** @var null */
        private static  $instance = null ;
        /**
         * WP_Radio_Chart_Widget constructor.
         */
        public function __construct()
        {
            add_action( 'wp_dashboard_setup', [ $this, 'dashboard_widgets' ] );
        }
        
        public function dashboard_widgets()
        {
            wp_add_dashboard_widget( 'wp_radio_chart', esc_html__( 'WP Radio Stats', 'wp-radio' ), [ $this, 'dashboard_widget_cb' ] );
            // Globalize the metaboxes array, this holds all the widgets for wp-admin.
            global  $wp_meta_boxes ;
            // Get the regular dashboard widgets array
            // (which already has our new widget but appended at the end).
            $default_dashboard = $wp_meta_boxes['dashboard']['normal']['core'];
            // Backup and delete our new dashboard widget from the end of the array.
            $wp_dark_mode_widget_backup = array(
                'wp_radio_chart' => $default_dashboard['wp_radio_chart'],
            );
            unset( $default_dashboard['wp_radio_chart'] );
            // Merge the two arrays together so our widget is at the beginning.
            $sorted_dashboard = array_merge( $wp_dark_mode_widget_backup, $default_dashboard );
            // Save the sorted array back into the original metaboxes.
            $wp_meta_boxes['dashboard']['normal']['core'] = $sorted_dashboard;
        }
        
        public function dashboard_widget_cb()
        {
            if ( !class_exists( 'WP_Radio_Statistics' ) ) {
                include_once WP_RADIO_INCLUDES . '/class-statistics.php';
            }
            $args = [
                'start_date' => date( 'Y-m-d', strtotime( '-7 Days' ) ),
                'end_date'   => date( 'Y-m-d', strtotime( 'tomorrow' ) ),
            ];
            $obj = WP_Radio_Statistics::instance( $args );
            ?>

            <div class="wp-radio-chart">

                <div class="chart-header">
                    <span><?php 
            esc_html_e( 'How many times the stations are played in each day.', 'wp-radio' );
            ?></span>

                    <select name="wp_radio_chart_period" id="wp_radio_chart_period">
                        <option value="7"><?php 
            esc_html_e( 'Last 7 Days', 'wp-radio' );
            ?></option>
                        <option value="30"><?php 
            esc_html_e( 'Last 30 Days', 'wp-radio' );
            ?></option>
                    </select>
                </div>

				<?php 
            $obj->chart();
            ?>
                    <div class="wp-radio-dash-widget-wrapper">
                        <div class="wp-radio-dash-widget">
                            <h2><?php 
            esc_html_e( 'View radio play stats inside WordPress Dashboard', 'wp-radio' );
            ?></h2>
                            <p><?php 
            esc_html_e( 'Upgrade to Pro and get access to the stats.', 'wp-radio' );
            ?></p>
                            <p>
                                <a href="<?php 
            echo  WP_RADIO_PRICING ;
            ?>" class="button button-primary"><?php 
            esc_html_e( 'Upgrade to Pro', 'wp-radio' );
            ?></a>
                            </p>

                        </div>
                    </div>
				<?php 
            ?>
            </div>
		<?php 
        }
        
        /**
         * @return WP_Radio_Chart_Widget|null
         */
        public static function instance()
        {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self();
            }
            return self::$instance;
        }
    
    }
}
WP_Radio_Chart_Widget::instance();