<?php

/** if class `WP_Radio_Settings` not exists yet */
if ( ! class_exists( 'WP_Radio_Settings' ) ) {

	class WP_Radio_Settings {
		private static $instance = null;
		private static $settings_api = null;

		public function __construct() {
			add_action( 'admin_init', array( $this, 'settings_fields' ) );
			add_action( 'admin_menu', array( $this, 'settings_menu' ) );
		}

		/**
		 * Registers settings section and fields
		 */
		public function settings_fields() {

			$is_pro = wr_fs()->can_use_premium_code__premium_only();

			$sections = apply_filters( 'wp_radio/settings_sections', array(
				array(
					'id'    => 'wp_radio_general_settings',
					'title' => sprintf( __( '%s General Settings', 'wp-radio' ), '<i class="dashicons dashicons-admin-generic"></i>' )
				),
				array(
					'id'    => 'wp_radio_display_settings',
					'title' => sprintf( __( '%s Display Settings', 'wp-radio' ), '<i class="dashicons dashicons-welcome-view-site"></i>' )
				),
				array(
					'id'    => 'wp_radio_image_settings',
					'title' => sprintf( __( '%s Image Settings', 'wp-radio' ), '<i class="dashicons dashicons-format-image"></i>' ),
				),
				array(
					'id'    => 'wp_radio_player_settings',
					'title' => sprintf( __( '%s Player Settings', 'wp-radio' ), '<i class="dashicons dashicons-controls-play"></i>' )
				),
				array(
					'id'    => 'wp_radio_style_settings',
					'title' => sprintf( __( '%s Color Settings', 'wp-radio' ), '<i class="dashicons dashicons-admin-customizer"></i>' )
				),
				array(
					'id'    => 'wp_radio_permalink_settings',
					'title' => sprintf( __( '%s Permalink Settings', 'wp-radio' ), '<i class="dashicons dashicons-admin-links"></i>' )
				),
			) );

			$fields = apply_filters( 'wp_radio/settings_fields', array(
				'wp_radio_general_settings' => [
					[
						'name'  => 'stations_page',
						'label' => __( 'Radio Archive Page :', 'wp-radio' ),
						'desc'  => __( 'Select the page which contains the [wp_radio_listing] shortcode for the radio stations listings.', 'wp-radio' ),
						'type'  => 'pages',
					],
					[
						'name'    => 'notification_email',
						'label'   => __( 'Notification Email :', 'wp-radio' ),
						'desc'    => __( 'Enter the email to receive email notification when a report or request to add a station is submitted.',
							'wp-radio' ),
						'type'    => 'text',
						'default' => get_option( 'admin_email' ),
					],
					[
						'name'    => 'delete_data',
						'label'   => __( 'Delete Data on Plugin Uninstalling :', 'wp-radio' ),
						'desc'    => __( 'Turn on to delete all the data (Stations, Settings) on uninstalling of this plugin.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'off',
					],
				],
				'wp_radio_display_settings' => [
					[
						'name'    => 'posts_per_page',
						'label'   => __( 'Stations Per Page :', 'wp-radio' ),
						'desc'    => __( 'Enter the number how many Stations will be displayed on the listing page.',
							'wp-radio' ),
						'type'    => 'select',
						'default' => 10,
						'options' => [
							'10' => __( '10', 'wp-radio' ),
							'15' => __( '15', 'wp-radio' ),
							'20' => __( '20', 'wp-radio' ),
							'30' => __( '30', 'wp-radio' ),
							'40' => __( '40', 'wp-radio' ),
							'50' => __( '50', 'wp-radio' ),
						],
					],
					[
						'name'    => 'listing_view',
						'label'   => __( 'Station Listing View :', 'wp-radio' ),
						'desc'    => __( 'Choose the Station Page Listing View. Left (List View), Right (Grid List View)',
							'wp-radio' ),
						'type'    => 'image_choose',
						'default' => 'list',
						'options' => [
							'list' => WP_RADIO_ASSETS . '/images/list.png',
							'grid' => WP_RADIO_ASSETS . '/images/grid.png',
						]
					],
					[
						'name'    => 'grid_column',
						'label'   => __( 'Grid Column Number :', 'wp-radio' ),
						'desc'    => __( 'Select the column number in the grid view. (Min:2 - Max: 6)', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 4,
						'min'     => 2,
						'max'     => 6,
					],
					[
						'name'    => 'listing_order',
						'label'   => __( 'Listing Order :', 'wp-radio' ),
						'desc'    => __( 'Select the listing order, how the stations will be sorted on the listing page.', 'wp-radio' ),
						'type'    => 'select',
						'default' => 'asc',
						'options' => [
							'asc'       => __( 'A-Z', 'wp-radio' ),
							'desc'      => __( 'Z-A', 'wp-radio' ),
							'date_desc' => __( 'New - Old', 'wp-radio' ),
							'date_asc'  => __( 'Old - New', 'wp-radio' ),
						],
					],
					[
						'name'    => 'ip_listing',
						'label'   => __( 'IP Based Listing :', 'wp-radio' ),
						'desc'    => __( 'If ON, visitors will see only their country’s stations on the listing page on the first visit <br> Else they will see all the stations.',
							'wp-radio' ),
						'type'    => 'switch',
						'default' => 'off',
					],
					[
						'name'    => 'listing_content',
						'label'   => __( 'Listing Description :', 'wp-radio' ),
						'desc'    => __( 'Show / hide the short station description in the station listing.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'off',
					],
					[
						'name'    => 'listing_genre',
						'label'   => __( 'Listing Genres :', 'wp-radio' ),
						'desc'    => __( 'Show / hide the station genres in the station listing.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'on',
					],
//					[
//						'name'    => 'single_next_prev',
//						'label'   => __( 'Show Next & Previous :', 'wp-radio' ),
//						'desc'    => __( 'Turn on/ off the Next, Previous station pagination under the content in the single station page.',
//							'wp-radio' ),
//						'type'    => 'switch',
//						'default' => 'off',
//					],

					[
						'name'    => 'show_regions',
						'label'   => __( 'Show Regions :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide the country state, city region list at the top of the listing.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => $is_pro ? 'on' : 'off',
					],

					[
						'name'    => 'show_search',
						'label'   => __( 'Show Filter :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide the stations filter on the listing  page.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => $is_pro ? 'on' : 'off',
					],

					[
						'name'    => 'listing_header',
						'label'   => __( 'Show Listing Header :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide listing <b>show per page</b> & <b>order</b> selection on the listing  page.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'on',
					],

					[
						'name'    => 'show_related',
						'label'   => __( 'Show Related Stations :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide related stations in the single station page.',
							'wp-radio' ),
						'type'    => 'switch',
						'default' => $is_pro ? 'on' : 'off',
					],

				],

				'wp_radio_image_settings'     => [
					[
						'name'    => 'listing_thumbnail_size',
						'label'   => __( 'Listing Thumbnail Size :', 'wp-radio' ),
						'desc'    => __( 'The station listing thumbnail image size.', 'wp-radio' ),
						'type'    => 'radio',
						'default' => 'auto',
						'options' => [
							'auto'   => 'Auto',
							'custom' => 'Custom',
						],
					],
					[
						'name'    => 'listing_thumbnail_width',
						'label'   => __( 'Listing Thumbnail Width :', 'wp-radio' ),
						'desc'    => __( 'Set the thumbnail width in the station listing (px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 100,
						'min'     => 50,
						'max'     => 500,
					],
					[
						'name'    => 'listing_thumbnail_height',
						'label'   => __( 'Listing Thumbnail Height :', 'wp-radio' ),
						'desc'    => __( 'Set the thumbnail height in the station listing (px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 100,
						'min'     => 30,
						'max'     => 500,
					],
					[
						'name'    => 'player_thumbnail_size',
						'label'   => __( 'Player Thumbnail Size :', 'wp-radio' ),
						'desc'    => __( 'The station player thumbnail image size.', 'wp-radio' ),
						'type'    => 'radio',
						'default' => 'auto',
						'options' => [
							'auto'   => 'Auto',
							'custom' => 'Custom',
						],
					],
					[
						'name'    => 'player_thumbnail_width',
						'label'   => __( 'Player Thumbnail Width :', 'wp-radio' ),
						'desc'    => __( 'Set the thumbnail width in the station player (px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 230,
						'min'     => 80,
						'max'     => 500,
					],
					[
						'name'    => 'player_thumbnail_height',
						'label'   => __( 'Player Thumbnail Height :', 'wp-radio' ),
						'desc'    => __( 'Set the thumbnail height in the station player (px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 100,
						'min'     => 40,
						'max'     => 500,
					],
				],
				'wp_radio_player_settings'    => [
					[
						'name'    => 'play_btn',
						'label'   => __( 'Player Type :', 'wp-radio' ),
						'desc'    => sprintf( __( '
					Play button behaviour for your website.
					<hr>
					<p><b>Default</b> - Stations will be played on the footer full-width player, where the play button will be clicked.</p>
					<hr>
					<p><b>Popup</b> - All the stations will be played on a new popup window.</p> %1$s', 'wp-radio' ), $is_pro ? '' : __('<p>Popup is only available in the premium version.</p>', 'wp-radio') ),
						'type'    => 'select',
						'options' => [
							'in_page' => __( 'Default', 'wp-radio' ),
							'popup'   => sprintf( __( 'Popup %s', 'wp-radio' ), $is_pro ? '' : '(Premium)' ),
						]
					],
					[
						'name'    => 'customize_popup_player',
						'label'   => __( 'Customize Popup Size? :', 'wp-radio' ),
						'desc'    => __( 'Want to customize the popup player width/ height.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'off',
					],
					[
						'name'    => 'popup_player_width',
						'label'   => __( 'Popup Player Width :', 'wp-radio' ),
						'desc'    => __( 'Set the popup player width(px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 420,
						'min'     => 100,
						'max'     => 1200,
					],
					[
						'name'    => 'popup_player_height',
						'label'   => __( 'Popup Player Height :', 'wp-radio' ),
						'desc'    => __( 'Set the popup player height (px).', 'wp-radio' ),
						'type'    => 'slider',
						'default' => 380,
						'min'     => 100,
						'max'     => 1000,
					],

//					[
//						'name'    => 'autoplay',
//						'label'   => __( 'Autoplay :', 'wp-radio' ),
//						'desc'    => __( 'Enable/ Disable autoplay in the station page.', 'wp-radio' ),
//						'type'    => 'switch',
//						'default' => 'off',
//					],

					[
						'name'    => 'player_volume',
						'label'   => __( 'Player Volume :', 'wp-radio' ),
						'desc'    => __( 'Set the player default volume.', 'wp-radio' ),
						'type'    => 'slider',
						'default' => '70',
					],

					[
						'name'    => 'next_prev',
						'label'   => __( 'Next Prev Buttons :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide next-previous  buttons in the radio player.', 'wp-radio' ),
						'type'    => 'switch',
						'default' => 'on',
					],

					[
						'name'    => 'hide_player',
						'label'   => __( 'Hide Bottom Player :', 'wp-radio' ),
						'desc'    => __( 'Show/ hide the footer bottom fixed player. You can play the radio station by hiding footer player.',
							'wp-radio' ),
						'type'    => 'switch',
						'default' => 'off',
					],

				],
				'wp_radio_style_settings'     => [
					[
						'name'    => 'listing_style_heading',
						'default' => __( 'Station Listing Color', 'wp-radio' ),
						'type'    => 'heading',
					],
					[
						'name'  => 'listing_bg_color',
						'label' => __( 'Listing Background Color :', 'wp-radio' ),
						'desc'  => __( 'Customize the station list background color.', 'wp-radio' ),
						'type'  => 'color',
					],
//					[
//						'name'  => 'listing_hover_bg',
//						'label' => __( 'Listing Background Hover Color :', 'wp-radio' ),
//						'desc'  => __( 'Customize the station listing hover background color.',
//							'wp-radio' ),
//						'type'  => 'color',
//
//					],
					[
						'name'  => 'listing_color',
						'label' => __( 'Listing Color :', 'wp-radio' ),
						'desc'  => __( 'Customize the listing icon & text color.', 'wp-radio' ),
						'type'  => 'color',
					],
					[
						'name'    => 'player_style_heading',
						'default' => __( 'Footer Player Color', 'wp-radio' ),
						'type'    => 'heading',
					],

					[
						'name'  => 'player_bg_color',
						'label' => __( 'Player Background Color:', 'wp-radio' ),
						'desc'  => __( 'Customize the background radio player background color.', 'wp-radio' ),
						'type'  => 'color',
					],
					[
						'name'  => 'player_color',
						'label' => __( 'Player Color :', 'wp-radio' ),
						'desc'  => __( 'Customize the player icon and text color.',
							'wp-radio' ),
						'type'  => 'color',
					],
				],
				'wp_radio_permalink_settings' => [
					[
						'name'    => 'permalink_structure',
						'label'   => __( 'Permalink Structure :', 'wp-radio' ),
						'desc'    => sprintf( __( '<hr> Customized the URL of the radio station page to be SEO friendly. %s', 'wp-radio' ), $is_pro ? '' : '<p>This feature is only available in the premium version.</p>' ),
						'default' => 'rewrite',
						'type'    => 'radio',
						'options' => [
							'rewrite'     => site_url( 'station/station-name' ),
							'postname'    => site_url( 'station-name' ),
							'countrycode' => site_url( 'country-code/station-name' ),
						]
					]
				],
			) );

			self::$settings_api = new WP_Military_Settings_API();

			//set sections and fields
			self::$settings_api->set_sections( $sections );
			self::$settings_api->set_fields( $fields );

			//initialize them
			self::$settings_api->admin_init();
		}

		/**
		 * Register the plugin page
		 */
		public function settings_menu() {
			add_submenu_page( 'edit.php?post_type=wp_radio',
				__( 'WP Radio Settings', 'wp-radio' ),
				__( 'Settings', 'wp-radio' ),
				'manage_options',
				'wpradio-settings',
				array( $this, 'settings_page' ) );
		}

		/**
		 * Display the plugin settings options page
		 */
		public function settings_page() {
			echo '<div class="wrap wp-radio-settings-page">';
			settings_errors();

			echo sprintf( "<h2>%s</h2>", __( 'WP Radio Settings', 'wp-radio' ) );
			self::$settings_api->show_settings();

			echo '</div>';
		}

		/**
		 * @return WP_Radio_Settings|null
		 */
		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

	}
}

WP_Radio_Settings::instance();