<?php

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'WP_Radio_Enqueue' ) ) {
	class WP_Radio_Enqueue {

		private static $instance = null;

		public function __construct() {
			add_action( 'wp_enqueue_scripts', [ $this, 'frontend_scripts' ] );
			add_action( 'admin_enqueue_scripts', [ $this, 'admin_enqueue' ] );
			add_action( 'elementor/frontend/before_enqueue_scripts', [ $this, 'elementor_scripts' ] );
		}

		/**
		 * Frontend Scripts
		 *
		 * @param $hook
		 */
		public static function frontend_scripts( $hook ) {

			/* enqueue frontend styles */
			//wp_enqueue_style( 'select2', WP_RADIO_ASSETS . '/vendor/select2/select2.min.css', false, '4.0.11' );
			wp_enqueue_style( 'wp-radio', WP_RADIO_ASSETS . '/css/frontend.css',
				[ 'dashicons', 'wp-components' ], WP_RADIO_VERSION );

			$custom_css = '';
			$is_popup   = ! empty( $_GET['player'] ) && sanitize_key( $_GET['player'] ) == 'popup';
			if ( $is_popup ) {
				$custom_css .= "
						html {
			                margin-top: 0 !important;
			            }
                    ";
			}

			$listing_selector = '.wp-radio-listing-wrap .wp-radio-listing';
			$listing_color    = wp_radio_get_settings( 'listing_color', '', 'wp_radio_style_settings' );
			$listing_bg_color = wp_radio_get_settings( 'listing_bg_color', '', 'wp_radio_style_settings' );

			$player_selector = '.wp-radio-player-container .wp-radio-player';
			$player_bg_color = wp_radio_get_settings( 'player_bg_color', '', 'wp_radio_style_settings' );
			$player_color    = wp_radio_get_settings( 'player_color', '', 'wp_radio_style_settings' );

			$listing_thumb_selector = '.wp-radio-listing .listing-thumbnail img.listing-thumb';
			$listing_thumb_size     = wp_radio_get_settings( 'listing_thumbnail_size', 'auto', 'wp_radio_image_settings' );
			$listing_thumb_width    = wp_radio_get_settings( 'listing_thumbnail_width', '', 'wp_radio_image_settings' );
			$listing_thumb_height   = wp_radio_get_settings( 'listing_thumbnail_height', '', 'wp_radio_image_settings' );

			$player_thumb_selector = '.wp-radio-player.shortcode .station-thumbnail';
			$player_thumb_size     = wp_radio_get_settings( 'player_thumbnail_size', 'auto', 'wp_radio_image_settings' );
			$player_thumb_width    = wp_radio_get_settings( 'player_thumbnail_width', '', 'wp_radio_image_settings' );
			$player_thumb_height   = wp_radio_get_settings( 'player_thumbnail_height', '', 'wp_radio_image_settings' );

			ob_start();
			//player colors
			if ( ! empty( $player_bg_color ) ) {
				printf( '%1$s {--wp-radio-player-bg-color: %2$s;}', $player_selector, $player_bg_color );
			}

			if ( ! empty( $player_color ) ) {
				printf( '%1$s {--wp-radio-player-text-color: %2$s;}', $player_selector, $player_color );
			}

			//listing colors
			if ( ! empty( $listing_bg_color ) ) {
				printf( '%1$s {--wp-radio-listing-bg-color: %2$s;}', $listing_selector, $listing_bg_color );
			}

			if ( ! empty( $listing_color ) ) {
				printf( '%1$s * {--wp-radio-listing-color: %2$s;}', $listing_selector, $listing_color );
			}

			if ( 'custom' == $listing_thumb_size ) {
				printf( '%1$s {width: %2$spx; height: %3$spx}', $listing_thumb_selector, $listing_thumb_width, $listing_thumb_height );
			}

			if ( 'custom' == $player_thumb_size ) {
				printf( '%1$s {width: %2$spx; height: %3$spx}', $player_thumb_selector, $player_thumb_width, $player_thumb_height );
			}

			$custom_css .= ob_get_clean();

			wp_add_inline_style( 'wp-radio', $custom_css );


			/* enqueue frontend script */
			wp_enqueue_script( 'jquery.hideseek', WP_RADIO_ASSETS . '/vendor/jquery.hideseek.min.js', [ 'jquery' ], WP_RADIO_VERSION, true );
			wp_enqueue_script( 'lazy-js', WP_RADIO_ASSETS . '/vendor/jquery.lazy.min.js', [ 'jquery' ], '1.7.10', true );

			wp_enqueue_script( 'wp-radio', WP_RADIO_ASSETS . '/js/frontend.min.js', [
				'wp-element',
				'wp-components',
				'wp-api-fetch',
				'wp-block-editor',
				'jquery',
				'jquery-migrate',
				'wp-util',
			], WP_RADIO_VERSION, true );


			/* localized script attached to 'wp-radio' */
			wp_localize_script( 'wp-radio', 'wpRadio', wp_radio_localize_array() );

			/* execute scripts after actions */
			do_action( 'wp_radio_scripts_after' );
		}

		/**
		 * Admin Scripts
		 *
		 * @param $hook
		 */
		public function admin_enqueue( $hook ) {

			wp_enqueue_style( 'select2', WP_RADIO_ASSETS . '/vendor/select2/select2.min.css', false, '4.0.11' );
			wp_enqueue_style( 'jquery.multi-select', WP_RADIO_ASSETS . '/vendor/lou-multi-select/css/multi-select.dist.css', false, '0.9.12' );
			wp_enqueue_style( 'wp-radio-admin', WP_RADIO_ASSETS . '/css/admin.css', false, WP_RADIO_VERSION );

			wp_enqueue_script( 'select2', WP_RADIO_ASSETS . '/vendor/select2/select2.min.js', [ 'jquery' ], '4.0.11', true );
			wp_enqueue_script( 'jquery.multi-select', WP_RADIO_ASSETS . '/vendor/lou-multi-select/js/jquery.multi-select.js', [ 'jquery' ], '0.9.12', true );
			wp_enqueue_script( 'jquery.hideseek', WP_RADIO_ASSETS . '/vendor/jquery.hideseek.min.js', [ 'jquery' ], WP_RADIO_VERSION, true );
			wp_enqueue_script( 'jquery.syotimer', WP_RADIO_ASSETS . '/vendor/jquery.syotimer.min.js', [ 'jquery' ], '', true );
			wp_enqueue_script( 'wp-color-picker-alpha', WP_RADIO_ASSETS . '/vendor/wp-color-picker-alpha.js', [
				'jquery',
				'wp-color-picker'
			], '', true );

			if ( function_exists( 'get_current_screen' ) && in_array( get_current_screen()->id, [
					'wp_radio_page_statistics',
					'dashboard'
				] ) ) {
				wp_enqueue_script( 'chart.js', WP_RADIO_ASSETS . '/vendor/Chart.bundle.min.js', [ 'jquery-ui-datepicker' ], '2.8.0', true );
			}

			wp_enqueue_script( 'wp-radio-admin', WP_RADIO_ASSETS . '/js/admin.min.js', [
				'wp-element',
				'wp-components',
				'wp-api-fetch',
				'wp-block-editor',
				'jquery',
				'wp-util'
			], WP_RADIO_VERSION, true );

			$localize_array = array(
				'isPremium'          => wr_fs()->can_use_premium_code__premium_only(),
				'pricingPage'        => WP_RADIO_PRICING,
				'pluginUrl'          => WP_RADIO_URL,
				'adminUrl'           => admin_url(),
				'ajaxUrl'            => admin_url( 'admin-ajax.php' ),
				'nonce'              => wp_create_nonce( 'wp-radio' ),
				'volume'             => wp_radio_get_settings( 'player_volume', 70, 'wp_radio_player_settings' ),
				'imported_countries' => get_option( 'wp_radio_imported_countries' ),
				'needs_update'       => (bool) get_option( 'wp_radio_needs_stations_update' ),
				'update_countries'   => (array) get_option( 'wp_radio_update_countries', [] ),

				'settings' => wp_radio_settings(),

				'i18n' => array(
					'alert_no_country'   => __( 'You need to select countries, before run the import', 'wp-radio' ),
					'running'            => __( 'Please wait, Import is running...', 'wp-radio' ),
					'no_country_found'   => __( 'No country found.', 'wp-radio' ),
					'update'             => __( 'Update', 'wp-radio' ),
					'updating'           => __( 'Updating', 'wp-radio' ),
					'imported'           => __( 'Imported: ', 'wp-radio' ),
					'count_title'        => __( 'Total station of the country', 'wp-radio' ),
					'premium'            => __( 'Premium', 'wp-radio' ),
					'select_add_country' => __( 'Search country to import', 'wp-radio' ),
					'get_premium'        => __( 'Upgrade to PRO', 'wp-radio' ),
					'premium_promo'      => __( 'to access total 52000+ stations of 190+ countries.', 'wp-radio' ),
					'selected_countries' => __( 'Selected Countries', 'wp-radio' ),
					'selected'           => __( 'Selected:', 'wp-radio' ),
					'remaining'          => __( 'Remaining:', 'wp-radio' ),
					'total_station'      => __( 'Total Station:', 'wp-radio' ),
					'import_more'        => __( 'Import More', 'wp-radio' ),
					'run_import'         => __( 'Run Importer', 'wp-radio' ),
					'hide_player'        => __( 'Hide Radio Player', 'wp-radio' ),
					'chartTitle'         => __( 'Stations play stats.', 'wp-radio' ),
					'cancelImport'       => __( 'Are you sure to cancel the import?', 'wp-radio' ),
					'importComplete'     => __( 'Hooray! Import is Complete.', 'wp-radio' ),
					'somethingWrong'     => __( 'Something went wrong. Please try again.', 'wp-radio' ),
					'maxImport'          => __( 'Maximum 20 countries can be imported in the free version.', 'wp-radio' ),
					'pleaseWait'         => __( 'Please wait, This may take several minutes.', 'wp-radio' ),
				),
			);

			wp_localize_script( 'wp-radio-admin', 'wpRadio', $localize_array );

		}

		public function elementor_scripts() {
			wp_enqueue_script( 'wp-radio-elementor', WP_RADIO_ASSETS . '/js/elementor.min.js', [ 'jquery' ], WP_RADIO_VERSION, true );
		}

		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}
}

WP_Radio_Enqueue::instance();




