<?php

defined( 'ABSPATH' ) || exit();

global $post, $wp_query;


$queried_object = get_queried_object();

$searchKeyword = ! empty( $_GET['keyword'] ) ? sanitize_text_field( urldecode( $_GET['keyword'] ) ) : '';
$searchCountry = ! empty( $_GET['country'] ) && 'all' != $_GET['country'] ? sanitize_text_field( $_GET['country'] ) : '';
$searchGenre   = ! empty( $_GET['genre'] ) ? intval( $_GET['genre'] ) : '';

$paginate = ! empty( $_GET['paginate'] ) ? intval( $_GET['paginate'] ) : 1;
$per_page = ! empty( $_GET['perpage'] ) ? intval( $_GET['perpage'] )
	: wp_radio_get_settings( 'posts_per_page', 10, 'wp_radio_display_settings' );

$sortby = 'title';
$sort   = ! empty( $_GET['sort'] ) ? sanitize_key( $_GET['sort'] )
	: wp_radio_get_settings( 'listing_order', 'asc', 'wp_radio_display_settings' );

if ( 'date_asc' == $sort ) {
	$sortby = 'date';
	$sort   = 'asc';
} elseif ( 'date_desc' == $sort ) {
	$sortby = 'date';
	$sort   = 'desc';
}

$is_grid = 'grid' == wp_radio_get_settings( 'listing_view', 'list', 'wp_radio_display_settings' );


$is_search = ! empty( $searchKeyword ) || ! empty( $searchCountry ) || ! empty( $searchGenre );
$is_tax    = is_tax( 'radio_country' ) || is_tax( 'radio_genre' );

$shortcode_filter = ! empty( $shortcode_args['country'] ) || ! empty( $shortcode_args['genre'] );

$is_custom = $shortcode_filter || $is_search || $is_tax;

$ip_listing = 'on' == wp_radio_get_settings( 'ip_listing', 'off', 'wp_radio_display_settings' );

$args = [
	'orderby'        => $sortby,
	'order'          => $sort,
	'paged'          => $paginate,
	'posts_per_page' => $per_page
];

$country = [];
$genre   = [];

if ( ! $is_custom && $ip_listing ) {
	$country[] = wp_radio_get_visitor_country();

} else {

	//search
	if ( ! empty( $searchKeyword ) ) {
		$args['s'] = $searchKeyword;
	}

	//country search
	if ( ! empty( $searchCountry ) ) {
		$country[] = $searchCountry;
	}

	//country archive taxonomy
	if ( is_tax( 'radio_country' ) ) {
		$country[] = $queried_object->slug;
	}

	//genre search
	if ( ! empty( $searchGenre ) ) {
		$genre[] = $searchGenre;
	}

	//genre taxonomy archive
	if ( is_tax( 'radio_genre' ) ) {
		$genre[] = intval( $queried_object->term_id );
	}


	$countries = ! empty( $shortcode_args['country'] ) ? array_filter( explode( ',', $shortcode_args['country'] ) ) : '';
	if ( ! empty( $countries ) ) {
		$country = $countries;
	}


	$genres = ! empty( $shortcode_args['genre'] ) ? array_filter( explode( ',', $shortcode_args['genre'] ) ) : '';
	if ( ! empty( $genres ) ) {
		foreach ( $genres as $g ) {
			$genre_term = get_term_by( 'slug', $g, 'radio_genre' );
			if ( $genre_term ) {
				$genre[] = $genre_term->term_id;
			}
		}
	}

	if ( ! empty( $genre ) ) {
		$args['tax_query'][] = array(
			'relation' => 'AND',
			'taxonomy' => 'radio_genre',
			'field'    => 'term_id',
			'terms'    => $genre,
		);
	}
}


if ( ! empty( array_filter( $country ) ) ) {
	$args['tax_query'][] = array(
		'relation' => 'AND',
		array(
			'taxonomy' => 'radio_country',
			'field'    => 'slug',
			'terms'    => $country,
		)
	);
}

$query = wp_radio_get_stations( $args, true );

$total     = $query->found_posts;
$pageCount = $query->max_num_pages;

$country_terms = get_terms( [ 'taxonomy' => 'radio_country', 'parent' => 0 ] );
$genre_terms   = get_terms( [ 'taxonomy' => 'radio_genre', 'parent' => 0 ] );

$country_list = [];
foreach ( $country_terms as $item ) {
	$country_list[ $item->slug ] = wp_radio_escape_quote( $item->name );
}

$genre_list = [];
foreach ( $genre_terms as $item ) {
	$genre_list[ $item->term_id ] = wp_radio_escape_quote( $item->name );
}


$country_term = get_term_by( 'slug', end( $country ), 'radio_country' );

$data_country = ! is_wp_error( $country_term ) && ! empty( $country_term ) && $country_term->count > 0 ? end( $country ) : '';

?>

<div class="wp-radio-listing-container"
     data-countries='<?php echo json_encode( $country_list ); ?>'
     data-genres='<?php echo json_encode( $genre_list ); ?>'
     data-pagecount='<?php echo $pageCount; ?>'
     data-keyword='<?php echo $searchKeyword; ?>'
     data-country='<?php echo $data_country; ?>'
     data-genre='<?php echo ! empty( $genre ) ? end( $genre ) : ''; ?>'
     data-paginate='<?php echo $paginate; ?>'
     data-perpage='<?php echo $per_page; ?>'
     data-sort='<?php echo $sort; ?>'
     data-regions='<?php echo ! empty( $country ) ? json_encode( wp_radio_get_regions( end( $country ) ) ) : "" ?>'
>
    <div class="ssc ssc-card">
        <div class="ssc-wrapper flex align-center justify-between">
            <div class="ssc-line w-40"></div>
            <div class="ssc-line w-20"></div>
            <div class="ssc-line w-20"></div>
        </div>
    </div>

    <div class="wp-radio-skeleton-wrap <?php echo $is_grid ? 'grid' : '' ?>">
		<?php
		for ( $i = 0; $i < ( $is_grid ? 12 : 10 ); $i ++ ) {

			if ( $is_grid ) { ?>
                <div class="ssc ssc-card">
                    <div class="ssc-wrapper flex align-center justify-between">
                        <div class="ssc-square w-100"></div>
                    </div>
                </div>
			<?php } else { ?>
                <div class="ssc ssc-card">
                    <div class="ssc-wrapper flex align-center justify-between">
                        <div class="ssc-square mr w-15"></div>

                        <div class="w-80">
                            <div class="ssc-head-line w-50 mb"></div>
                            <div class="ssc-line w-70"></div>
                            <div class="ssc-line w-30"></div>

                            <div class="w-40 flex align-center justify-between">
                                <div class="ssc-line w-22"></div>
                                <div class="ssc-line w-22"></div>
                                <div class="ssc-line w-22"></div>
                                <div class="ssc-line w-22"></div>
                            </div>
                        </div>

                        <div class="ssc-circle"></div>
                    </div>

                </div>
			<?php }
		} ?>
    </div>
</div>