<?php

defined( 'ABSPATH' ) || exit();

$post_id = get_the_ID();

$url = get_the_permalink( $post_id );

$country_terms = get_terms( [ 'taxonomy' => 'radio_country', 'parent' => 0 ] );
$genre_terms   = get_terms( [ 'taxonomy' => 'radio_genre', 'parent' => 0 ] );

$country_list = [];
foreach ( $country_terms as $item ) {
	$country_list[ $item->slug ] = wp_radio_escape_quote( $item->name );
}

$genre_list = [];
foreach ( $genre_terms as $item ) {
	$genre_list[ $item->slug ] = wp_radio_escape_quote( $item->name );
}


$title     = wp_radio_escape_quote( get_the_title( $post_id ) );
$content   = wp_radio_escape_quote( get_post_field( 'post_content', $post_id ) );
$thumbnail = wp_radio_get_meta( $post_id, 'logo', WP_RADIO_ASSETS . '/images/placeholder.jpg' );
$slogan    = wp_radio_get_meta( $post_id, 'slogan' );

$website   = wp_radio_get_meta( $post_id, 'website' );
$facebook  = wp_radio_get_meta( $post_id, 'facebook' );
$twitter   = wp_radio_get_meta( $post_id, 'twitter' );
$wikipedia = wp_radio_get_meta( $post_id, 'wikipedia' );

$contacts = array_filter( [
	'Address' => wp_radio_get_meta( $post_id, 'address' ),
	'Email'   => wp_radio_get_meta( $post_id, 'email' ),
	'Phone'   => wp_radio_get_meta( $post_id, 'phone' ),
] );

$data = [
	'id'        => $post_id,
	'title'     => $title,
	'content'   => $content,
	'thumbnail' => $thumbnail,
	'slogan'    => $slogan,
	'link'      => $url,
	'stream'    => apply_filters( 'wp_radio/stream_url', wp_radio_get_meta( $post_id, 'stream_url' ), $post_id ),
	'website'   => $website,
	'facebook'  => $facebook,
	'twitter'   => $twitter,
	'wikipedia' => $wikipedia,
	'contacts'  => $contacts,
	'locations' => wp_radio_get_location( $post_id ),
	'genres'    => wp_radio_get_genres( $post_id ),
]

?>

<div id="wp-radio-single-container"
     data-data='<?php echo json_encode( $data ); ?>'
     data-countries='<?php echo json_encode( $country_list ); ?>'
     data-genres='<?php echo json_encode( $genre_list ); ?>'
>

    <div class="wp-radio-single" itemScope itemType="https://schema.org/RadioStation">


        <div class="wp-radio-page-title">
            <div class="wp-radio-thumbnail">
                <img src=<?php echo $thumbnail; ?> alt="<?php echo $title; ?>" title="<?php echo $title; ?>"
                     itemProp="image"/>
            </div>

            <div class='wp-radio-player-status'>
                <span class="status-text-live">LIVE</span>
                <span class="status-dot"></span>
            </div>
        </div>

        <h1 class="entry-title" itemProp="headline"><?php echo $title; ?></h1>

		<?php if ( ! empty( $slogan ) ) { ?>
            <span class='station-slogan'><?php echo $slogan; ?></span>
		<?php } ?>


        <div class="wp-radio-header">

            <div class="wp-radio-details">

            </div>


        </div>

        <div class="wp-radio-body">
            <p class="description" itemProp="description"><?php echo $content; ?></p>
        </div>

        <div class="wp-radio-footer">
            <div class="wp-radio-info">
				<?php

				if ( ! empty( $website ) ) { ?>
                    <a href="<?php echo $website ?>" target="_blank"><i class="dashicons dashicons-external"></i>Website</a>
				<?php }

				if ( ! empty( $facebook ) ) { ?>
                    <a href="<?php echo $facebook ?>" target="_blank"><i
                                class="dashicons dashicons-facebook"></i>Facebook</a>
				<?php }

				if ( ! empty( $twitter ) ) { ?>
                    <a href="<?php echo $twitter ?>" target="_blank"><i class="dashicons dashicons-twitter"></i>Twitter</a>
				<?php }

				if ( ! empty( $wikipedia ) ) { ?>
                    <a href="<?php echo $wikipedia ?>" target="_blank"><i class="dashicons dashicons-external"></i>Wikipedia</a>
				<?php } ?>
            </div>
        </div>

		<?php
		if ( ! empty( $contacts = array_filter( $contacts ) ) ) { ?>

            <div class="station-contacts">
                <h3 class="contacts-title"><?php esc_html_e( 'Contacts', 'wp-radio' ); ?></h3>

				<?php
				foreach ( $contacts as $label => $value ) {
					$value = str_replace( [ 'Address: ', 'Email: ', 'Phone: ' ], [ '', '', '' ], $value );
					printf( '<p><b>%1$s : </b> %2$s</p>', $label, trim( $value ) );
				}
				?>
            </div>

		<?php }
		?>

    </div>
</div>